@@ -3,10 +3,10 @@
 """
 
 from base64 import b64encode
-from typing import Any, Optional, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
-import aiohttp
 import aiofiles
+import aiohttp
 import requests
 from requests.compat import urljoin
 
@@ -41,26 +41,25 @@ BASE_QUERY = {
 class TreeHoleClient:
     """
     树洞交互客户端，低程度封装
-
-    Parameters
-    ----------
-    token: str
-        用户 token，32 位字符串，可在树洞页面获取
-    header: dict[str, str]
-        额外的请求头，可选
-    base_param: dict[str, str]
-        额外的请求参数，可选
-    base_url: str
-        其他树洞 API 地址，可选
     """
 
     def __init__(
         self,
         token: str,
-        header: Optional[dict[str, str]] = None,
-        base_param: Optional[dict[str, str]] = None,
+        header: Optional[Dict[str, str]] = None,
+        base_param: Optional[Dict[str, str]] = None,
         base_url: Optional[str] = None,
     ) -> None:
+        """
+        - token:
+            用户 token，32 位字符串，可在树洞页面获取
+        - header:
+            额外的请求头，可选
+        - base_param:
+            额外的请求参数，可选
+        - base_url:
+            其他树洞 API 地址，可选
+        """
         self.__token = token
         self.__header = {**REQUEST_HEADER, **(header or {})}
         self.__base_param = {
@@ -83,12 +82,12 @@ class TreeHoleClient:
         return self.__token
 
     @property
-    def header(self) -> dict[str, str]:
+    def header(self) -> Dict[str, str]:
         """请求头，只读"""
         return self.__header
 
     @property
-    def base_param(self) -> dict[str, str]:
+    def base_param(self) -> Dict[str, str]:
         """请求参数，只读"""
         return self.__base_param
 
@@ -118,7 +117,7 @@ class TreeHoleClient:
             logger.error(
                 "Failed to get reponse, status code: %s, response: %s",
                 response.status_code,
-                response.text.encode("utf-8").decode("unicode_escape"),
+                response.reason,
             )
             return False
         else:
@@ -130,39 +129,37 @@ class TreeHoleClient:
             logger.error(
                 "Failed to get reponse, status code: %s, response: %s",
                 response.status,
-                response.text(),
+                response.reason,
             )
             return False
         else:
             return True
 
     @staticmethod
-    def __is_valid_json_code(response: dict[str, Any]) -> bool:
+    def __is_valid_json_code(response: Dict[str, Any]) -> bool:
         # TODO: To be tested for exact error
         return response["code"] == 0
 
     @staticmethod
-    def __is_valid_json_captcha(response: dict[str, Any]) -> bool:
+    def __is_valid_json_captcha(response: Dict[str, Any]) -> bool:
         # TODO: To be tested for exact error
         return not response["captcha"]
 
     def get_hole_image(
         self, hole: GenericHole
-    ) -> Union[tuple[bytes, str], tuple[None, None]]:
+    ) -> Union[Tuple[bytes, str], Tuple[None, None]]:
         """
         获取树洞图片
 
         Parameters
         ----------
-        hole: Hole | ListHole | AttentionHole
+        - hole:
             任一树洞类
 
         Returns
         -------
-        1: bytes | None
-            图片二进制数据，不包含图片或请求错误则返回 `None`
-        2: str | None
-            图片类型，不包含图片或请求错误则返回 `None`
+        1. 图片二进制数据，不包含图片或请求错误则返回 `None`
+        2. 图片类型，不包含图片或请求错误则返回 `None`
         """
         if hole.type == "image":
             assert hole.url is not None
@@ -174,21 +171,18 @@ class TreeHoleClient:
 
     async def get_hole_image_async(
         self, hole: GenericHole
-    ) -> Union[tuple[bytes, str], tuple[None, None]]:
+    ) -> Union[Tuple[bytes, str], Tuple[None, None]]:
         """
         异步获取树洞图片
 
         Parameters
         ----------
-        hole: Hole | ListHole | AttentionHole
-            任一树洞类
+        - hole: 任一树洞类
 
         Returns
         -------
-        1: bytes | None
-            图片二进制数据，不包含图片或请求错误则返回 `None`
-        2: str | None
-            图片类型，不包含图片或请求错误则返回 `None`
+        1. 图片二进制数据，不包含图片或请求错误则返回 `None`
+        2. 图片类型，不包含图片或请求错误则返回 `None`
         """
         if hole.type == "image":
             assert hole.url is not None
@@ -205,21 +199,18 @@ class TreeHoleClient:
 
     def get_comment(
         self, pid: Union[int, str]
-    ) -> Union[tuple[list[Comment], int], tuple[None, None]]:
+    ) -> Union[Tuple[List[Comment], int], Tuple[None, None]]:
         """
         获取树洞评论
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
+        - pid: 树洞 ID
 
         Returns
         -------
-        1: list[Comment] | None
-            评论列表，请求错误则返回 `None`
-        2: int | None
-            是否已关注，请求错误则返回 `None`
+        1. 评论列表，请求错误则返回 `None`
+        2. 是否已关注，请求错误则返回 `None`
         """
 
         if not self.__is_num(pid):
@@ -244,21 +235,18 @@ class TreeHoleClient:
 
     async def get_comment_async(
         self, pid: Union[int, str]
-    ) -> Union[tuple[list[Comment], int], tuple[None, None]]:
+    ) -> Union[Tuple[List[Comment], int], Tuple[None, None]]:
         """
         异步获取树洞评论
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
+        - pid: 树洞 ID
 
         Returns
         -------
-        1: list[Comment] | None
-            评论列表，请求错误则返回 `None`
-        2: int | None
-            是否已关注，请求错误则返回 `None`
+        1. 评论列表，请求错误则返回 `None`
+        2. 是否已关注，请求错误则返回 `None`
         """
 
         if not self.__is_num(pid):
@@ -285,21 +273,18 @@ class TreeHoleClient:
 
     def get_hole(
         self, pid: Union[int, str]
-    ) -> Union[tuple[Hole, int], tuple[None, None]]:
+    ) -> Union[Tuple[Hole, int], Tuple[None, None]]:
         """
         获取单个树洞
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
+        - pid: 树洞 ID
 
         Returns
         -------
-        1: Hole | None
-            树洞，请求错误则返回 `None`
-        2: int | None
-            查询的时间戳，请求错误则返回 `None`
+        1. 树洞，请求错误则返回 `None`
+        2. 查询的时间戳，请求错误则返回 `None`
         """
         if not self.__is_num(pid):
             raise ValueError("pid must be an integer or string of interger")
@@ -321,21 +306,18 @@ class TreeHoleClient:
 
     async def get_hole_async(
         self, pid: Union[int, str]
-    ) -> Union[tuple[Hole, int], tuple[None, None]]:
+    ) -> Union[Tuple[Hole, int], Tuple[None, None]]:
         """
         异步获取单个树洞
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
+        - pid: 树洞 ID
 
         Returns
         -------
-        1: Hole | None
-            树洞，请求错误则返回 `None`
-        2: int | None
-            查询的时间戳，请求错误则返回 `None`
+        1. 树洞，请求错误则返回 `None`
+        2. 查询的时间戳，请求错误则返回 `None`
         """
         if not self.__is_num(pid):
             raise ValueError("pid must be an integer or string of interger")
@@ -359,21 +341,18 @@ class TreeHoleClient:
 
     def get_holes(
         self, page: Union[int, str] = 1
-    ) -> Union[tuple[list[ListHole], int], tuple[None, None]]:
+    ) -> Union[Tuple[List[ListHole], int], Tuple[None, None]]:
         """
         获取首页树洞
 
         Parameters
         ----------
-        page: int | str
-            列表页码，默认为 1
+        - page: 列表页码，默认为 1
 
         Returns
         -------
-        1: list[ListHole] | None
-            首页树洞列表，请求错误则返回 `None`
-        2: int | None
-            查询的时间戳，请求错误则返回 `None`
+        1. 首页树洞列表，请求错误则返回 `None`
+        2. 查询的时间戳，请求错误则返回 `None`
         """
         if not self.__is_num(page):
             raise ValueError("page must be an integer or string of interger")
@@ -395,21 +374,18 @@ class TreeHoleClient:
 
     async def get_holes_async(
         self, page: Union[int, str] = 1
-    ) -> Union[tuple[list[ListHole], int], tuple[None, None]]:
+    ) -> Union[Tuple[List[ListHole], int], Tuple[None, None]]:
         """
         异步获取首页树洞
 
         Parameters
         ----------
-        page: int | str
-            列表页码，默认为 1
+        - page: 列表页码，默认为 1
 
         Returns
         -------
-        1: list[ListHole] | None
-            首页树洞列表，请求错误则返回 `None`
-        2: int | None
-            查询的时间戳，请求错误则返回 `None`
+        1. 首页树洞列表，请求错误则返回 `None`
+        2. 查询的时间戳，请求错误则返回 `None`
         """
         if not self.__is_num(page):
             raise ValueError("page must be an integer or string of interger")
@@ -433,21 +409,18 @@ class TreeHoleClient:
 
     def get_attention(
         self, page: Union[int, str] = 1
-    ) -> Union[tuple[list[AttentionHole], int], tuple[None, None]]:
+    ) -> Union[Tuple[List[AttentionHole], int], Tuple[None, None]]:
         """
         获取关注树洞
 
         Parameters
         ----------
-        page: int | str
-            列表页码，默认为 1
+        - page: 列表页码，默认为 1
 
         Returns
         -------
-        1: list[AttentionHole] | None
-            关注树洞列表，请求错误则返回 `None`
-        2: int | None
-            查询的时间戳，请求错误则返回 `None`
+        1. 关注树洞列表，请求错误则返回 `None`
+        2. 查询的时间戳，请求错误则返回 `None`
         """
         if not self.__is_num(page):
             raise ValueError("page must be an integer or string of interger")
@@ -471,21 +444,18 @@ class TreeHoleClient:
 
     async def get_attention_async(
         self, page: Union[int, str] = 1
-    ) -> Union[tuple[list[AttentionHole], int], tuple[None, None]]:
+    ) -> Union[Tuple[List[AttentionHole], int], Tuple[None, None]]:
         """
         异步获取关注树洞
 
         Parameters
         ----------
-        page: int | str
-            列表页码，默认为 1
+        - page: 列表页码，默认为 1
 
         Returns
         -------
-        1: list[AttentionHole] | None
-            关注树洞列表，请求错误则返回 `None`
-        2: int | None
-            查询的时间戳，请求错误则返回 `None`
+        1. 关注树洞列表，请求错误则返回 `None`
+        2. 查询的时间戳，请求错误则返回 `None`
         """
         if not self.__is_num(page):
             raise ValueError("page must be an integer or string of interger")
@@ -511,24 +481,21 @@ class TreeHoleClient:
 
     def get_search(
         self,
-        keywords: Union[str, list[str]],
+        keywords: Union[str, List[str]],
         page: Union[int, str] = 1,
         page_size: Union[int, str] = 50,
-    ) -> Optional[list[Hole]]:
+    ) -> Optional[List[Hole]]:
         """
         搜索树洞
 
         Parameters
         ----------
-        keywords: str | list[str]
-            搜索关键词
-        page: int | str
-            列表页码，默认为 1
+        - keywords: 搜索关键词
+        - page: 列表页码，默认为 1
 
         Returns
         -------
-        list[Hole] | None
-            搜索结果，请求错误则返回 `None`
+        1. 搜索结果，请求错误则返回 `None`
         """
         if not self.__is_num(page):
             raise ValueError("page must be an integer or string of interger")
@@ -559,24 +526,21 @@ class TreeHoleClient:
 
     async def get_search_async(
         self,
-        keywords: Union[str, list[str]],
+        keywords: Union[str, List[str]],
         page: Union[int, str] = 1,
         page_size: Union[int, str] = 50,
-    ) -> Optional[list[Hole]]:
+    ) -> Optional[List[Hole]]:
         """
         异步搜索树洞
 
         Parameters
         ----------
-        keywords: str | list[str]
-            搜索关键词
-        page: int | str
-            列表页码，默认为 1
+        - keywords: 搜索关键词
+        - page: 列表页码，默认为 1
 
         Returns
         -------
-        list[Hole] | None
-            搜索结果，请求错误则返回 `None`
+        1. 搜索结果，请求错误则返回 `None`
         """
         if not self.__is_num(page):
             raise ValueError("page must be an integer or string of interger")
@@ -615,15 +579,12 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        text: str
-            树洞内容
-        image: bytes | str
-            树洞图片 (二进制数据或文件名)
+        - text: 树洞内容
+        - image: 树洞图片 (二进制数据或文件名)
 
         Returns
         -------
-        int | None
-            发布成功的树洞 ID，请求错误则返回 `None`
+        1. 发布成功的树洞 ID，请求错误则返回 `None`
         """
         if not text and not image:
             raise EmptyError("Empty post is not allowed")
@@ -675,15 +636,12 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        text: str
-            树洞内容
-        image: bytes | str
-            树洞图片 (二进制数据或文件名)
+        - text: 树洞内容
+        - image: 树洞图片 (二进制数据或文件名)
 
         Returns
         -------
-        int | None
-            发布成功的树洞 ID，请求错误则返回 `None`
+        1. 发布成功的树洞 ID，请求错误则返回 `None`
         """
         if not text and not image:
             raise EmptyError("Empty post is not allowed")
@@ -739,17 +697,13 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
-        text: str
-            评论内容
-        reply_to: int | str
-            回复的用户昵称或标号（非层号），`None` 为回复洞主（默认）
+        - pid: 树洞 ID
+        - text: 评论内容
+        - reply_to: 回复的用户昵称或标号（非层号），`None` 为回复洞主（默认）
 
         Returns
         -------
-        int | None
-            回复成功的树洞 ID，请求错误则返回 `None`
+        1. 回复成功的树洞 ID，请求错误则返回 `None`
         """
         if not text:
             raise EmptyError("Empty post is not allowed")
@@ -797,17 +751,13 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
-        text: str
-            评论内容
-        reply_to: int | str
-            回复的用户昵称或标号（非层号），`None` 为回复洞主（默认）
+        - pid: 树洞 ID
+        - text: 评论内容
+        - reply_to: 回复的用户昵称或标号（非层号），`None` 为回复洞主（默认）
 
         Returns
         -------
-        int | None
-            回复成功的树洞 ID，请求错误则返回 `None`
+        1. 回复成功的树洞 ID，请求错误则返回 `None`
         """
         if not text:
             raise EmptyError("Empty post is not allowed")
@@ -850,13 +800,11 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
+        - pid: 树洞 ID
 
         Returns
         -------
-        bool
-            是否关注成功，已关注的树洞返回 `False`
+        1. 是否关注成功，已关注的树洞返回 `False`
         """
         if not self.__is_num(pid):
             raise ValueError("pid must be an integer or string of interger")
@@ -889,13 +837,11 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
+        - pid: 树洞 ID
 
         Returns
         -------
-        bool
-            是否关注成功，已关注的树洞返回 `False`
+        1. 是否关注成功，已关注的树洞返回 `False`
         """
         if not self.__is_num(pid):
             raise ValueError("pid must be an integer or string of interger")
@@ -928,13 +874,11 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
+        - pid: 树洞 ID
 
         Returns
         -------
-        bool
-            是否取消关注成功，未关注的树洞返回 `True`
+        1. 是否取消关注成功，未关注的树洞返回 `True`
         """
         if not self.__is_num(pid):
             raise ValueError("pid must be an integer or string of interger")
@@ -967,13 +911,11 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
+        - pid: 树洞 ID
 
         Returns
         -------
-        bool
-            是否取消关注成功，未关注的树洞返回 `True`
+        1. 是否取消关注成功，未关注的树洞返回 `True`
         """
         if not self.__is_num(pid):
             raise ValueError("pid must be an integer or string of interger")
@@ -1002,23 +944,19 @@ class TreeHoleClient:
 
     def post_toggle_attention(
         self, pid: Union[int, str], two_factor: bool = False
-    ) -> Union[tuple[bool, Optional[int]], tuple[None, None]]:
+    ) -> Union[Tuple[bool, Optional[int]], Tuple[None, None]]:
         """
         切换关注状态
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
-        two_factor: bool
-            是否启用双重验证（默认为 `False`）
+        - pid: 树洞 ID
+        - two_factor: 是否启用双重验证（默认为 `False`）
 
         Returns
         -------
-        1: bool | None
-            是否成功切换关注状态，请求错误则返回 `None`
-        2: int | None
-            当前关注状态，`1` 为关注，`0` 为未关注，请求错误则返回 `None`
+        1. 是否成功切换关注状态，请求错误则返回 `None`
+        2. 当前关注状态，`1` 为关注，`0` 为未关注，请求错误则返回 `None`
         """
         _, attention = self.get_comment(pid)
         if attention is None:
@@ -1038,23 +976,19 @@ class TreeHoleClient:
 
     async def post_toggle_attention_async(
         self, pid: Union[int, str], two_factor: bool = False
-    ) -> Union[tuple[bool, Optional[int]], tuple[None, None]]:
+    ) -> Union[Tuple[bool, Optional[int]], Tuple[None, None]]:
         """
         异步切换关注状态
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
-        two_factor: bool
-            是否启用双重验证（默认为 `False`）
+        - pid: 树洞 ID
+        - two_factor: 是否启用双重验证（默认为 `False`）
 
         Returns
         -------
-        1: bool | None
-            是否成功切换关注状态，请求错误则返回 `None`
-        2: int | None
-            当前关注状态，`1` 为关注，`0` 为未关注，请求错误则返回 `None`
+        1. 是否成功切换关注状态，请求错误则返回 `None`
+        2. 当前关注状态，`1` 为关注，`0` 为未关注，请求错误则返回 `None`
         """
         _, attention = await self.get_comment_async(pid)
         if attention is None:
@@ -1078,15 +1012,12 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
-        reason: str
-            举报理由（默认为空）
+        - pid: 树洞 ID
+        - reason: 举报理由（默认为空）
 
         Returns
         -------
-        bool
-            是否举报成功
+        1. 是否举报成功
         """
         if not self.__is_num(pid):
             raise ValueError("pid must be an integer or string of interger")
@@ -1118,15 +1049,12 @@ class TreeHoleClient:
 
         Parameters
         ----------
-        pid: int | str
-            树洞 ID
-        reason: str
-            举报理由（默认为空）
+        - pid: 树洞 ID
+        - reason: 举报理由（默认为空）
 
         Returns
         -------
-        bool
-            是否举报成功
+        1. 是否举报成功
         """
         if not self.__is_num(pid):
             raise ValueError("pid must be an integer or string of interger")
